@@ -1,12 +1,12 @@
 /*
- * SPDX-FileCopyrightText: 2019-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2019-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #pragma once
 
-#include "kldap_export.h"
+#include "kldapwidgets_export.h"
 
 #include <QWidget>
 
@@ -15,14 +15,14 @@ class QPushButton;
 class QToolButton;
 class QListWidgetItem;
 
-namespace KLDAP
+namespace KLDAPWidgets
 {
 class LdapClientSearchConfig;
 /**
  * @brief The LdapConfigureWidget class
  * @author Laurent Montel <montel@kde.org>
  */
-class KLDAP_EXPORT LdapConfigureWidget : public QWidget
+class KLDAPWIDGETS_EXPORT LdapConfigureWidget : public QWidget
 {
     Q_OBJECT
 public:
@@ -45,7 +45,7 @@ Q_SIGNALS:
     void changed(bool);
 
 private:
-    void initGUI();
+    KLDAPWIDGETS_NO_EXPORT void initGUI();
 
     QListWidget *mHostListView = nullptr;
 
@@ -55,7 +55,6 @@ private:
 
     QToolButton *mUpButton = nullptr;
     QToolButton *mDownButton = nullptr;
-    KLDAP::LdapClientSearchConfig *const mClientSearchConfig;
+    KLDAPWidgets::LdapClientSearchConfig *const mClientSearchConfig;
 };
 }
-
