@@ -1,19 +1,22 @@
 /*
- * SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
 
 #pragma once
 
-#include "kldap_export.h"
+#include "kldapwidgets_export.h"
 #include <KConfigGroup>
 #include <QObject>
-namespace KLDAP
+namespace KLDAPCore
+{
+class LdapServer;
+}
+namespace KLDAPWidgets
 {
 class LdapClient;
-class LdapServer;
-class KLDAP_EXPORT LdapSearchClientReadConfigServerJob : public QObject
+class KLDAPWIDGETS_EXPORT LdapSearchClientReadConfigServerJob : public QObject
 {
     Q_OBJECT
 public:
@@ -21,26 +24,25 @@ public:
     ~LdapSearchClientReadConfigServerJob() override;
 
     void start();
-    Q_REQUIRED_RESULT bool canStart() const;
+    [[nodiscard]] bool canStart() const;
 
-    Q_REQUIRED_RESULT int currentIndex() const;
+    [[nodiscard]] int currentIndex() const;
     void setCurrentIndex(int currentIndex);
 
-    Q_REQUIRED_RESULT bool active() const;
+    [[nodiscard]] bool active() const;
     void setActive(bool active);
 
-    Q_REQUIRED_RESULT KConfigGroup config() const;
+    [[nodiscard]] KConfigGroup config() const;
     void setConfig(const KConfigGroup &config);
 
     LdapClient *ldapClient() const;
     void setLdapClient(LdapClient *ldapClient);
 
 private:
-    void slotConfigLoaded(const KLDAP::LdapServer &server);
+    KLDAPWIDGETS_NO_EXPORT void slotConfigLoaded(const KLDAPCore::LdapServer &server);
     LdapClient *mLdapClient = nullptr;
     KConfigGroup mConfig;
     int mCurrentIndex = -1;
     bool mActive = false;
 };
 }
-
