@@ -1,5 +1,5 @@
 /*
- * SPDX-FileCopyrightText: 2020-2022 Laurent Montel <montel@kde.org>
+ * SPDX-FileCopyrightText: 2020-2024 Laurent Montel <montel@kde.org>
  *
  * SPDX-License-Identifier: LGPL-2.0-or-later
  */
@@ -7,25 +7,24 @@
 #pragma once
 
 #include <QListWidget>
-#include <kldap/ldapserver.h>
-namespace KLDAP
+#include <kldapcore/ldapserver.h>
+namespace KLDAPWidgets
 {
 class LdapWidgetItem : public QListWidgetItem
 {
 public:
     explicit LdapWidgetItem(QListWidget *parent, bool isActive = false);
 
-    void setServer(const KLDAP::LdapServer &server);
+    void setServer(const KLDAPCore::LdapServer &server);
 
-    const KLDAP::LdapServer &server() const;
+    const KLDAPCore::LdapServer &server() const;
 
     void setIsActive(bool isActive);
 
-    Q_REQUIRED_RESULT bool isActive() const;
+    [[nodiscard]] bool isActive() const;
 
 private:
-    KLDAP::LdapServer mServer;
+    KLDAPCore::LdapServer mServer;
     bool mIsActive = false;
 };
 }
-
