@@ -1,7 +1,7 @@
 /*
  * MasterConfigurationPage.cpp - page for configuring master application
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -41,11 +41,16 @@ MasterConfigurationPage::MasterConfigurationPage() :
 {
 	ui->setupUi(this);
 
-	connect( ui->openUserConfigurationDirectory, &QPushButton::clicked,
-			 this, &MasterConfigurationPage::openUserConfigurationDirectory );
+	Configuration::UiMapping::setFlags(ui->advancedSettingsGroupBox, Configuration::Property::Flag::Advanced);
 
-	connect( ui->openScreenshotDirectory, &QPushButton::clicked,
-			 this, &MasterConfigurationPage::openScreenshotDirectory );
+	connect(ui->openUserConfigurationDirectory, &QPushButton::clicked,
+			 this, &MasterConfigurationPage::openUserConfigurationDirectory);
+
+	connect(ui->openScreenshotDirectory, &QPushButton::clicked,
+			 this, &MasterConfigurationPage::openScreenshotDirectory);
+
+	connect(ui->openConfigurationTemplatesDirectory, &QPushButton::clicked,
+			 this, &MasterConfigurationPage::openConfigurationTemplatesDirectory);
 
 	populateFeatureComboBox();
 }
@@ -121,14 +126,21 @@ void MasterConfigurationPage::disableFeature()
 
 void MasterConfigurationPage::openUserConfigurationDirectory()
 {
-	FileSystemBrowser(FileSystemBrowser::ExistingDirectory).exec(ui->userConfigurationDirectory);
+	FileSystemBrowser(FileSystemBrowser::ExistingDirectory, this).exec(ui->userConfigurationDirectory);
 }
 
 
 
 void MasterConfigurationPage::openScreenshotDirectory()
 {
-	FileSystemBrowser( FileSystemBrowser::ExistingDirectory ).exec( ui->screenshotDirectory );
+	FileSystemBrowser(FileSystemBrowser::ExistingDirectory, this).exec(ui->screenshotDirectory);
+}
+
+
+
+void MasterConfigurationPage::openConfigurationTemplatesDirectory()
+{
+	FileSystemBrowser(FileSystemBrowser::ExistingDirectory, this).exec(ui->configurationTemplatesDirectory);
 }
 
 
@@ -160,7 +172,7 @@ void MasterConfigurationPage::updateFeatureLists()
 	ui->allFeaturesListWidget->clear();
 	ui->disabledFeaturesListWidget->clear();
 
-	for( const auto& feature : qAsConst( VeyonCore::featureManager().features() ) )
+	for( const auto& feature : std::as_const( VeyonCore::featureManager().features() ) )
 	{
 		if( feature.testFlag( Feature::Flag::Master ) == false ||
 			feature.testFlag( Feature::Flag::Meta ) ||
