@@ -1,7 +1,7 @@
 /*
  * ServiceConfigurationPage.cpp - page for configuring service application
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -25,7 +25,6 @@
 #include <QMessageBox>
 #include <QTimer>
 
-#include "FileSystemBrowser.h"
 #include "VeyonConfiguration.h"
 #include "PluginManager.h"
 #include "ServiceConfigurationPage.h"
@@ -43,8 +42,9 @@ ServiceConfigurationPage::ServiceConfigurationPage() :
 {
 	ui->setupUi(this);
 
-	Configuration::UiMapping::setFlags( ui->networkPortNumbersGroupBox, Configuration::Property::Flag::Advanced );
-	Configuration::UiMapping::setFlags( ui->miscNetworkSettingsGroupBox, Configuration::Property::Flag::Advanced );
+	Configuration::UiMapping::setFlags(ui->networkPortNumbersGroupBox, Configuration::Property::Flag::Advanced);
+	Configuration::UiMapping::setFlags(ui->miscSettingsGroupBox, Configuration::Property::Flag::Advanced);
+	Configuration::UiMapping::setFlags(ui->sessionMetaDataGroupBox, Configuration::Property::Flag::Advanced);
 
 	updateServiceControl();
 	populateVncServerPluginComboBox();
@@ -83,7 +83,7 @@ void ServiceConfigurationPage::connectWidgetsToProperties()
 
 void ServiceConfigurationPage::applyConfiguration()
 {
-	VeyonServiceControl serviceControl( this );
+	VeyonServiceControl serviceControl(this);
 
 	if( serviceControl.isServiceRunning() &&
 		QMessageBox::question( this, tr( "Restart %1 Service" ).arg( VeyonCore::applicationName() ),
@@ -92,8 +92,7 @@ void ServiceConfigurationPage::applyConfiguration()
 				"Restart it now?" ).arg( VeyonCore::applicationName() ),
 			QMessageBox::Yes | QMessageBox::No, QMessageBox::Yes ) == QMessageBox::Yes )
 	{
-		serviceControl.stopService();
-		serviceControl.startService();
+		serviceControl.restartService();
 	}
 }
 
@@ -101,7 +100,7 @@ void ServiceConfigurationPage::applyConfiguration()
 
 void ServiceConfigurationPage::startService()
 {
-	VeyonServiceControl( this ).startService();
+	VeyonServiceControl(this).startService();
 
 	updateServiceControl();
 }
@@ -110,7 +109,7 @@ void ServiceConfigurationPage::startService()
 
 void ServiceConfigurationPage::stopService()
 {
-	VeyonServiceControl( this ).stopService();
+	VeyonServiceControl(this).stopService();
 
 	updateServiceControl();
 }
@@ -154,7 +153,7 @@ void ServiceConfigurationPage::updateVncServerPluginConfigurationWidget()
 
 void ServiceConfigurationPage::populateVncServerPluginComboBox()
 {
-	for( auto pluginObject : qAsConst( VeyonCore::pluginManager().pluginObjects() ) )
+	for( auto pluginObject : std::as_const( VeyonCore::pluginManager().pluginObjects() ) )
 	{
 		auto pluginInterface = qobject_cast<PluginInterface *>( pluginObject );
 		auto vncServerPluginInterface = qobject_cast<VncServerPluginInterface *>( pluginObject );
