@@ -1,7 +1,7 @@
 /*
  * NetworkObjectDirectory.cpp - base class for network object directory implementations
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,14 +24,13 @@
 
 #include <QTimer>
 
-#include "VeyonConfiguration.h"
-#include "VeyonCore.h"
 #include "NetworkObjectDirectory.h"
 
 
 NetworkObjectDirectory::NetworkObjectDirectory( QObject* parent ) :
 	QObject( parent ),
 	m_updateTimer( new QTimer( this ) ),
+	m_propagateChangedObjectsTimer(new QTimer(this)),
 	m_objects(),
 	m_invalidObject( NetworkObject::Type::None ),
 	m_rootObject( NetworkObject::Type::Root ),
@@ -39,6 +38,11 @@ NetworkObjectDirectory::NetworkObjectDirectory( QObject* parent ) :
 {
 	connect( m_updateTimer, &QTimer::timeout, this, &NetworkObjectDirectory::update );
 
+	connect(m_propagateChangedObjectsTimer, &QTimer::timeout,
+			this, &NetworkObjectDirectory::propagateChildObjectChanges);
+	m_propagateChangedObjectsTimer->setInterval(ObjectChangePropagationTimeout);
+	m_propagateChangedObjectsTimer->setSingleShot(true);
+
 	// insert root item
 	m_objects[rootId()] = {};
 }
@@ -62,9 +66,7 @@ void NetworkObjectDirectory::setUpdateInterval( int interval )
 
 const NetworkObjectList& NetworkObjectDirectory::objects( const NetworkObject& parent ) const
 {
-	if( parent.type() == NetworkObject::Type::Root ||
-		parent.type() == NetworkObject::Type::Location ||
-		parent.type() == NetworkObject::Type::DesktopGroup )
+	if( parent.type() == NetworkObject::Type::Root || parent.isContainer() )
 	{
 		const auto it = m_objects.constFind( parent.modelId() );
 		if( it != m_objects.end() )
@@ -88,14 +90,12 @@ const NetworkObject& NetworkObjectDirectory::object( NetworkObject::ModelId pare
 	const auto it = m_objects.constFind( parent );
 	if( it != m_objects.end() )
 	{
-		int index = 0;
 		for( const auto& entry : *it )
 		{
 			if( entry.modelId() == object )
 			{
 				return entry;
 			}
-			++index;
 		}
 	}
 
@@ -285,21 +285,22 @@ void NetworkObjectDirectory::addOrUpdateObject( const NetworkObject& networkObje
 
 	if( index < 0 )
 	{
-		Q_EMIT objectsAboutToBeInserted( parent, objectList.count(), 1 );
+		Q_EMIT objectsAboutToBeInserted(parent.modelId(), objectList.count(), 1);
 
 		objectList.append( completeNetworkObject );
-		if( completeNetworkObject.type() == NetworkObject::Type::Location ||
-			completeNetworkObject.type() == NetworkObject::Type::DesktopGroup )
+		if( completeNetworkObject.isContainer() )
 		{
 			m_objects[completeNetworkObject.modelId()] = {};
 		}
 
 		Q_EMIT objectsInserted();
+
+		propagateChildObjectChange(parent.modelId());
 	}
 	else if( objectList[index].exactMatch( completeNetworkObject ) == false )
 	{
 		objectList.replace( index, completeNetworkObject );
-		Q_EMIT objectChanged( parent, index );
+		propagateChildObjectChange(parent.modelId());
 	}
 }
 
@@ -320,15 +321,15 @@ void NetworkObjectDirectory::removeObjects( const NetworkObject& parent, const N
 	{
 		if( removeObjectFilter( *it ) )
 		{
-			if( it->type() == NetworkObject::Type::Location ||
-				it->type() == NetworkObject::Type::DesktopGroup )
+			if( it->isContainer() )
 			{
 				groupsToRemove.append( it->modelId() );
 			}
 
-			Q_EMIT objectsAboutToBeRemoved( parent, index, 1 );
+			Q_EMIT objectsAboutToBeRemoved(parent.modelId(), index, 1);
 			it = objectList.erase( it );
 			Q_EMIT objectsRemoved();
+			propagateChildObjectChange(parent.modelId());
 		}
 		else
 		{
@@ -374,3 +375,42 @@ void NetworkObjectDirectory::setObjectPopulated( const NetworkObject& networkObj
 		}
 	}
 }
+
+
+
+void NetworkObjectDirectory::propagateChildObjectChange(NetworkObject::ModelId objectId, int depth)
+{
+	if (objectId != 0)
+	{
+		if (m_changedObjectIds.contains(objectId))
+		{
+			m_changedObjectIds.removeAll(objectId);
+		}
+
+		m_changedObjectIds.append(objectId);
+
+		propagateChildObjectChange(parentId(objectId), depth+1);
+
+		if (depth == 0)
+		{
+			m_propagateChangedObjectsTimer->stop();
+			m_propagateChangedObjectsTimer->start();
+		}
+	}
+}
+
+
+
+void NetworkObjectDirectory::propagateChildObjectChanges()
+{
+	for (auto it = m_changedObjectIds.constBegin(), end = m_changedObjectIds.constEnd();
+		 it != end; ++it)
+	{
+		const auto parentObjectId = parentId(*it);
+		const auto childIndex = index(parentObjectId, *it);
+
+		Q_EMIT objectChanged(parentObjectId, childIndex);
+	}
+
+	m_changedObjectIds.clear();
+}
