@@ -1,7 +1,7 @@
 /*
  * VncClientProtocol.cpp - implementation of the VncClientProtocol class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -72,7 +72,6 @@ VncClientProtocol::VncClientProtocol( QIODevice* socket, const Password& vncPass
 	m_state( Disconnected ),
 	m_vncPassword( vncPassword ),
 	m_serverInitMessage(),
-	m_pixelFormat( { 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0 } ),
 	m_framebufferWidth( 0 ),
 	m_framebufferHeight( 0 )
 {
@@ -115,26 +114,40 @@ bool VncClientProtocol::read() // Flawfinder: ignore
 
 
 
-bool VncClientProtocol::setPixelFormat( rfbPixelFormat pixelFormat )
+void VncClientProtocol::setPixelFormat(rfbPixelFormat pixelFormat)
 {
-	rfbSetPixelFormatMsg spf;
-
-	spf.type = rfbSetPixelFormat;
-	spf.pad1 = 0;
-	spf.pad2 = 0;
-	spf.format = pixelFormat;
-	spf.format.redMax = qFromBigEndian(pixelFormat.redMax);
-	spf.format.greenMax = qFromBigEndian(pixelFormat.greenMax);
-	spf.format.blueMax = qFromBigEndian(pixelFormat.blueMax);
-
-	return m_socket->write( reinterpret_cast<const char *>( &spf ), sz_rfbSetPixelFormatMsg ) == sz_rfbSetPixelFormatMsg;
+	m_pixelFormat = pixelFormat;
 }
 
 
 
-bool VncClientProtocol::setEncodings( const QVector<uint32_t>& encodings )
+void VncClientProtocol::setEncodings(const QVector<uint32_t>& encodings)
 {
-	if( encodings.size() > MAX_ENCODINGS )
+	m_encodings = encodings;
+}
+
+
+
+bool VncClientProtocol::sendPixelFormat()
+{
+	rfbSetPixelFormatMsg spf{};
+
+	spf.type = rfbSetPixelFormat;
+	spf.pad1 = 0;
+	spf.pad2 = 0;
+	spf.format = m_pixelFormat;
+	spf.format.redMax = qToBigEndian(spf.format.redMax);
+	spf.format.greenMax = qToBigEndian(spf.format.greenMax);
+	spf.format.blueMax = qToBigEndian(spf.format.blueMax);
+
+	return m_socket->write(reinterpret_cast<const char *>(&spf), sz_rfbSetPixelFormatMsg) == sz_rfbSetPixelFormatMsg;
+}
+
+
+
+bool VncClientProtocol::sendEncodings()
+{
+	if (m_encodings.size() > MAX_ENCODINGS)
 	{
 		return false;
 	}
@@ -148,16 +161,16 @@ bool VncClientProtocol::setEncodings( const QVector<uint32_t>& encodings )
 	setEncodingsMsg->pad = 0;
 	setEncodingsMsg->nEncodings = 0;
 
-	for( auto encoding : encodings )
+	for (const auto encoding : std::as_const(m_encodings))
 	{
-		encs[setEncodingsMsg->nEncodings++] = qFromBigEndian<uint32_t>( encoding );
+		encs[setEncodingsMsg->nEncodings++] = qToBigEndian<uint32_t>(encoding);
 	}
 
 	const auto len = sz_rfbSetEncodingsMsg + setEncodingsMsg->nEncodings * 4;
 
-	setEncodingsMsg->nEncodings = qFromBigEndian(setEncodingsMsg->nEncodings);
+	setEncodingsMsg->nEncodings = qToBigEndian(setEncodingsMsg->nEncodings);
 
-	return m_socket->write( buf, len ) == len;
+	return m_socket->write(buf, len) == len;
 }
 
 
@@ -241,8 +254,8 @@ bool VncClientProtocol::readProtocol()
 			return false;
 		}
 
-		const auto match = QRegularExpression{ QStringLiteral("RFB (\\d\\d\\d)\\.(\\d\\d\\d)\n") }
-							   .match( QString::fromUtf8( protocol ) );
+		static const QRegularExpression rfbRX{QStringLiteral("RFB (\\d\\d\\d)\\.(\\d\\d\\d)\n")};
+		const auto match = rfbRX.match(QString::fromUtf8(protocol));
 
 		if( match.hasMatch() == false ||
 			match.captured( 1 ).toInt() != 3 ||
@@ -283,7 +296,7 @@ bool VncClientProtocol::receiveSecurityTypes()
 		}
 
 		const auto securityTypeList = m_socket->read( securityTypeCount );
-		if( securityTypeList.count() != securityTypeCount )
+		if( securityTypeList.size() != securityTypeCount )
 		{
 			vCritical() << "could not read security types!";
 			m_socket->close();
@@ -378,8 +391,8 @@ bool VncClientProtocol::receiveServerInitMessage()
 {
 	rfbServerInitMsg message;
 
-	if( m_socket->bytesAvailable() >= sz_rfbServerInitMsg &&
-			m_socket->peek( reinterpret_cast<char *>( &message ), sz_rfbServerInitMsg ) == sz_rfbServerInitMsg )
+	if (m_socket->bytesAvailable() >= sz_rfbServerInitMsg &&
+		m_socket->peek(reinterpret_cast<char *>(&message), sz_rfbServerInitMsg) == sz_rfbServerInitMsg)
 	{
 		const auto nameLength = qFromBigEndian( message.nameLength );
 
@@ -609,6 +622,9 @@ bool VncClientProtocol::handleRect( QBuffer& buffer, rfbFramebufferUpdateRectHea
 	case rfbEncodingZYWRLE:
 		return handleRectEncodingZRLE( buffer );
 
+	case rfbEncodingTight:
+		return handleRectEncodingTight(buffer, rectHeader);
+
 	case rfbEncodingExtDesktopSize:
 		return handleRectEncodingExtDesktopSize(buffer);
 
@@ -619,7 +635,11 @@ bool VncClientProtocol::handleRect( QBuffer& buffer, rfbFramebufferUpdateRectHea
 		return true;
 
 	default:
-		vCritical() << "Unsupported rect encoding" << rectHeader.encoding;
+		vCritical() << "Unsupported rect encoding" <<
+#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
+					   Qt::hex <<
+#endif
+					   rectHeader.encoding;
 		m_socket->close();
 		break;
 	}
@@ -665,8 +685,8 @@ bool VncClientProtocol::handleRectEncodingCoRRE( QBuffer& buffer, uint bytesPerP
 
 
 bool VncClientProtocol::handleRectEncodingHextile( QBuffer& buffer,
-													const rfbFramebufferUpdateRectHeader rectHeader,
-													uint bytesPerPixel )
+												   const rfbFramebufferUpdateRectHeader rectHeader,
+												   uint bytesPerPixel )
 {
 	const uint rx = rectHeader.r.x;
 	const uint ry = rectHeader.r.y;
@@ -785,6 +805,147 @@ bool VncClientProtocol::handleRectEncodingZRLE(QBuffer &buffer)
 
 
 
+bool VncClientProtocol::handleRectEncodingTight(QBuffer& buffer,
+												const rfbFramebufferUpdateRectHeader rectHeader)
+{
+	static const auto readCompactLength = [](QBuffer& buffer) -> int64_t
+	{
+		int64_t len;
+		uint8_t b;
+
+		if (buffer.read(reinterpret_cast<char *>(&b), 1 ) != 1)
+		{
+			return -1;
+		}
+
+		len = int(b) & 0x7f;
+
+		if (b & 0x80)
+		{
+			if (buffer.read(reinterpret_cast<char *>(&b), 1) != 1)
+			{
+				return -1;
+			}
+
+			len |= (int(b) & 0x7f) << 7;
+
+			if (b & 0x80)
+			{
+				if (buffer.read(reinterpret_cast<char *>(&b), 1) != 1)
+				{
+					return -1;
+				}
+
+				len |= (int(b) & 0xff) << 14;
+			}
+		}
+
+		return len;
+	};
+
+	auto bitsPerPixel = m_pixelFormat.bitsPerPixel;
+	if (bitsPerPixel == 32 &&
+		m_pixelFormat.depth == 24 &&
+		m_pixelFormat.redMax == 255 &&
+		m_pixelFormat.greenMax == 255 &&
+		m_pixelFormat.blueMax == 255)
+	{
+		bitsPerPixel = 24;
+	}
+
+	const auto bytesPerPixel = bitsPerPixel / 8;
+
+	uint8_t compCtl = 255;
+	if (buffer.read(reinterpret_cast<char *>(&compCtl), 1) != 1)
+	{
+		return false;
+	}
+
+	compCtl >>= 4; // ignore compression stream reset bits
+
+	if ((compCtl & rfbTightNoZlib) == rfbTightNoZlib)
+	{
+		compCtl &= ~(rfbTightNoZlib);
+	}
+
+	if (compCtl == rfbTightFill)
+	{
+		return buffer.read(bytesPerPixel).size() == bytesPerPixel;
+	}
+
+	if (compCtl == rfbTightJpeg)
+	{
+		const auto dataLength = readCompactLength(buffer);
+		return buffer.read(dataLength).size() == dataLength;
+	}
+
+	if (compCtl > rfbTightMaxSubencoding)
+	{
+		vWarning() << "bad subencoding value received";
+		return false;
+	}
+
+	if (compCtl & rfbTightExplicitFilter)
+	{
+		uint8_t filterId = 0;
+		if (buffer.read(reinterpret_cast<char *>(&filterId), 1) != 1)
+		{
+			return false;
+		}
+
+		switch (filterId)
+		{
+		case rfbTightFilterCopy:
+			break;
+		case rfbTightFilterPalette:
+		{
+			uint8_t numColors;
+			if (buffer.read(reinterpret_cast<char *>(&numColors), 1) != 1)
+			{
+				return false;
+			}
+			const auto tightRectColors = numColors + 1;
+			if (tightRectColors < 2)
+			{
+				return false;
+			}
+			const auto rectBytes = tightRectColors * bytesPerPixel;
+			if (buffer.read(rectBytes).size() != rectBytes)
+			{
+				return false;
+			}
+			bitsPerPixel = tightRectColors == 2 ? 1 : 8;
+			break;
+		}
+		case rfbTightFilterGradient:
+			break;
+		default:
+			vWarning() << "invalid filter ID";
+			return false;
+		}
+	}
+
+	const int MaximumUncompressedSize = 12;
+
+	const int rowSize = (rectHeader.r.w * bitsPerPixel + 7) / 8;
+	const int uncompressedRectSize = rectHeader.r.h * rowSize;
+	if (uncompressedRectSize < MaximumUncompressedSize)
+	{
+		return buffer.read(uncompressedRectSize).size() == uncompressedRectSize;
+	}
+
+	const auto compressedLength = readCompactLength(buffer);
+	if (compressedLength <= 0)
+	{
+		vWarning() << "bad compressed length received";
+		return false;
+	}
+
+	return buffer.read(compressedLength).size() == compressedLength;
+}
+
+
+
 bool VncClientProtocol::handleRectEncodingExtDesktopSize(QBuffer& buffer)
 {
 	rfbExtDesktopSizeMsg extDesktopSizeMsg;
