@@ -1,7 +1,7 @@
 /*
  * NetworkObjectFilterProxyModel.cpp - implementation of NetworkObjectFilterProxyModel
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -61,30 +61,77 @@ void NetworkObjectFilterProxyModel::setComputerExcludeFilter( const QStringList&
 
 
 
+void NetworkObjectFilterProxyModel::setEmptyGroupsExcluded(bool enabled)
+{
+	beginResetModel();
+	m_excludeEmptyGroups = enabled;
+	endResetModel();
+}
+
+
+void NetworkObjectFilterProxyModel::setComputersExcluded(bool enabled)
+{
+	beginResetModel();
+	m_excludeComputers = enabled;
+	endResetModel();
+}
+
+
+
 bool NetworkObjectFilterProxyModel::filterAcceptsRow( int sourceRow, const QModelIndex& sourceParent ) const
 {
-	const auto rowIndex = sourceModel()->index(sourceRow, 0, sourceParent);
-	const auto objectType = NetworkObject::Type(sourceModel()->data(rowIndex, NetworkObjectModel::TypeRole).toInt());
+	const auto index = sourceModel()->index(sourceRow, 0, sourceParent);
+	const auto objectType = NetworkObject::Type(sourceModel()->data(index, NetworkObjectModel::TypeRole).toInt());
+	if (filterAcceptsRowRecursive(index))
+	{
+		return true;
+	}
+
+	if (NetworkObject::isContainer(objectType))
+	{
+		return parentContainerAccepted(index);
+	}
+
+	return false;
+}
+
+
+
+bool NetworkObjectFilterProxyModel::filterAcceptsRowRecursive(const QModelIndex& index) const
+{
+	const auto objectType = NetworkObject::Type(sourceModel()->data(index, NetworkObjectModel::TypeRole).toInt());
 
 	if (objectType == NetworkObject::Type::Host)
 	{
+		if (m_excludeComputers)
+		{
+			return false;
+		}
+
+		const auto parentAccepted = m_groupList.isEmpty() ||
+									parentContainerAccepted(sourceModel()->parent(index));
+		if (parentAccepted == false)
+		{
+			return false;
+		}
+
 		if( m_computerExcludeList.isEmpty() )
 		{
 			return true;
 		}
 
-		const auto hostAddress = sourceModel()->data(rowIndex, NetworkObjectModel::HostAddressRole).toString();
+		const auto hostAddress = sourceModel()->data(index, NetworkObjectModel::HostAddressRole).toString();
 
 		return m_computerExcludeList.contains( hostAddress, Qt::CaseInsensitive ) == false;
 	}
-	else if(NetworkObject::isContainer(objectType))
+	else if (NetworkObject::isContainer(objectType))
 	{
-		if (sourceModel()->canFetchMore(rowIndex))
+		if (sourceModel()->canFetchMore(index))
 		{
-			sourceModel()->fetchMore(rowIndex);
+			sourceModel()->fetchMore(index);
 		}
 
-		const auto rows = sourceModel()->rowCount(rowIndex);
+		const auto rows = sourceModel()->rowCount(index);
 
 		if (m_excludeEmptyGroups && rows == 0)
 		{
@@ -98,20 +145,26 @@ bool NetworkObjectFilterProxyModel::filterAcceptsRow( int sourceRow, const QMode
 
 		for (int i = 0; i < rows; ++i)
 		{
-			const auto objectType = NetworkObject::Type(sourceModel()->data(sourceModel()->index(i, 0, rowIndex),
-																			NetworkObjectModel::TypeRole).toInt());
+			const auto rowIndex = sourceModel()->index(i, 0, index);
+			const auto objectType = NetworkObject::Type(sourceModel()->data(rowIndex, NetworkObjectModel::TypeRole).toInt());
 
-			if (objectType == NetworkObject::Type::Location || objectType == NetworkObject::Type::DesktopGroup)
+			if (NetworkObject::isContainer(objectType) && filterAcceptsRowRecursive(rowIndex))
 			{
-				if (filterAcceptsRow(i, rowIndex))
-				{
-					return true;
-				}
+				return true;
 			}
 		}
 
-		return m_groupList.contains(sourceModel()->data(rowIndex).toString());
+		return m_groupList.contains(sourceModel()->data(index).toString());
 	}
 
 	return true;
 }
+
+
+
+bool NetworkObjectFilterProxyModel::parentContainerAccepted(const QModelIndex& index) const
+{
+	return index.isValid() &&
+			(m_groupList.contains(sourceModel()->data(index).toString()) ||
+			 parentContainerAccepted(sourceModel()->parent(index)));
+}
