@@ -1,7 +1,7 @@
 /*
  * NetworkObjectOverlayDataModel.h - overlay model for NetworkObjectModel to provide extra data
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -31,16 +31,24 @@ class NetworkObjectOverlayDataModel : public KExtraColumnsProxyModel
 {
 	Q_OBJECT
 public:
-	explicit NetworkObjectOverlayDataModel( const QString& overlayDataHeader,
-								   QObject *parent = nullptr );
+	explicit NetworkObjectOverlayDataModel(const QStringList& overlayDataHeaders,
+										   QObject *parent = nullptr);
 
-	QVariant extraColumnData( const QModelIndex &parent, int row, int extraColumn, int role ) const override;
+	QVariant data(const QModelIndex &index, int role = Qt::DisplayRole) const override;
 
-	bool setExtraColumnData( const QModelIndex &parent, int row, int extraColumn, const QVariant &data, int role ) override;
+	bool setData(const QModelIndex& index, const QVariant& value, int role = Qt::DisplayRole) override;
+
+	QVariant extraColumnData(const QModelIndex& parent, int row, int extraColumn, int role = Qt::DisplayRole) const override;
+
+	bool setExtraColumnData(const QModelIndex& parent, int row, int extraColumn, const QVariant& data, int role = Qt::DisplayRole) override;
 
 
 private:
+	NetworkObject::Uid lookupNetworkObjectId(const QModelIndex& index) const;
+	NetworkObject::Uid lookupNetworkObjectId(const QModelIndex& parent, int row) const;
+
 	int m_overlayDataRole;
-	QHash<NetworkObject::Uid, QVariant> m_overlayData;
+	QHash<NetworkObject::Uid, QMap<int, QVariant>> m_overlayData;
+	QHash<NetworkObject::Uid, QList<QVariant>> m_extraColumnsData;
 
 };
