@@ -1,7 +1,7 @@
 /*
  * NetworkObjectTreeModel.h - data model returning hierarchically grouped network objects
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -51,13 +51,13 @@ public:
 
 
 private:
-	void beginInsertObjects( const NetworkObject& parent, int index, int count );
+	void beginInsertObjects(NetworkObject::ModelId parentId, int index, int count);
 	void endInsertObjects();
 
-	void beginRemoveObjects( const NetworkObject& parent, int index, int count );
+	void beginRemoveObjects(NetworkObject::ModelId parentId, int index, int count);
 	void endRemoveObjects();
 
-	void updateObject( const NetworkObject& parent, int index );
+	void updateObject(NetworkObject::ModelId parent, int index );
 
 	QModelIndex objectIndex( NetworkObject::ModelId object, int column = 0 ) const;
 	const NetworkObject& object( const QModelIndex& index ) const;
