@@ -2,7 +2,7 @@
  * DemoServer.cpp - multi-threaded slim VNC-server for demo-purposes (optimized
  *                   for lot of clients accessing server in read-only-mode)
  *
- * Copyright (c) 2006-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2006-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -30,7 +30,6 @@
 #include "DemoConfiguration.h"
 #include "DemoServer.h"
 #include "DemoServerConnection.h"
-#include "VeyonConfiguration.h"
 #include "VncClientProtocol.h"
 
 
@@ -47,7 +46,8 @@ DemoServer::DemoServer( int vncServerPort, const Password& vncServerPassword, co
 	m_framebufferUpdateTimer( this ),
 	m_lastFullFramebufferUpdate(),
 	m_requestFullFramebufferUpdate( false ),
-	m_keyFrame( 0 )
+	m_keyFrame(0),
+	m_bandwidthLimit(qMax(1, m_configuration.bandwidthLimit()) * 1024)
 {
 	connect( m_vncServerSocket, &QTcpSocket::readyRead, this, &DemoServer::readFromVncServer );
 	connect( m_vncServerSocket, &QTcpSocket::disconnected, this, &DemoServer::reconnectToVncServer );
@@ -250,9 +250,32 @@ void DemoServer::enqueueFramebufferUpdateMessage( const QByteArray& message )
 		if( m_keyFrameTimer.elapsed() > 1 )
 		{
 			const auto memTotal = queueSize / 1024;
+			const auto bandwidth = qMax<int>(1, (memTotal * 1000) / m_keyFrameTimer.elapsed());
+			const auto clientCount = qMin(1, findChildren<DemoServerConnection *>().count());
+			const auto totalBandwidth = bandwidth * clientCount;
+
+			auto newQuality = m_quality;
+			if (totalBandwidth > m_bandwidthLimit)
+			{
+				newQuality = qMax(int(MinimumQuality),
+								  m_quality - qMax(1, int(totalBandwidth / m_bandwidthLimit)));
+			}
+			else if (totalBandwidth < m_bandwidthLimit * 4 / 5)
+			{
+				newQuality = qMin(int(MaximumQuality),
+								  m_quality + qMax(1, int(m_bandwidthLimit / totalBandwidth)));
+			}
+
+			if (newQuality != m_quality)
+			{
+				setVncServerEncodings(newQuality);
+			}
+
 			vDebug() << "message count:" << m_framebufferUpdateMessages.size()
 					 << "queue size (KB):" << memTotal
-					 << "throughput (KB/s):" << ( memTotal * 1000 ) / m_keyFrameTimer.elapsed();
+					 << "total bandwidth (KB/s):" << totalBandwidth << "of" << m_bandwidthLimit
+					 << "bandwidth per client (KB/s):" << bandwidth
+					 << "quality" << m_quality;
 		}
 		m_keyFrameTimer.restart();
 		++m_keyFrame;
@@ -278,7 +301,7 @@ qint64 DemoServer::framebufferUpdateMessageQueueSize() const
 {
 	qint64 size = 0;
 
-	for( const auto& message : qAsConst( m_framebufferUpdateMessages ) )
+	for( const auto& message : std::as_const( m_framebufferUpdateMessages ) )
 	{
 		size += message.size();
 	}
@@ -293,7 +316,7 @@ void DemoServer::start()
 	vDebug();
 
 	setVncServerPixelFormat();
-	setVncServerEncodings();
+	setVncServerEncodings(DefaultQuality);
 
 	m_requestFullFramebufferUpdate = true;
 
@@ -325,25 +348,32 @@ bool DemoServer::setVncServerPixelFormat()
 	format.pad1 = 0;
 	format.pad2 = 0;
 
-	return m_vncClientProtocol->setPixelFormat( format );
+	m_vncClientProtocol->setPixelFormat(format);
+
+	return m_vncClientProtocol->sendPixelFormat();
 }
 
 
 
-bool DemoServer::setVncServerEncodings()
+bool DemoServer::setVncServerEncodings(int quality)
 {
-	return m_vncClientProtocol->
-			setEncodings( {
-							  rfbEncodingUltraZip,
-							  rfbEncodingUltra,
-							  rfbEncodingCopyRect,
-							  rfbEncodingHextile,
-							  rfbEncodingCoRRE,
-							  rfbEncodingRRE,
-							  rfbEncodingRaw,
-							  rfbEncodingCompressLevel9,
-							  rfbEncodingQualityLevel7,
-							  rfbEncodingNewFBSize,
-							  rfbEncodingLastRect
-						  } );
+	m_quality = quality;
+
+	m_vncClientProtocol->setEncodings({
+										  rfbEncodingTight,
+										  rfbEncodingZYWRLE,
+										  rfbEncodingZRLE,
+										  rfbEncodingUltra,
+										  rfbEncodingCopyRect,
+										  rfbEncodingHextile,
+										  rfbEncodingCoRRE,
+										  rfbEncodingRRE,
+										  rfbEncodingRaw,
+										  rfbEncodingCompressLevel9,
+										  rfbEncodingQualityLevel0 + quality,
+										  rfbEncodingNewFBSize,
+										  rfbEncodingLastRect
+									  });
+
+	return m_vncClientProtocol->sendEncodings();
 }
