@@ -1,4 +1,4 @@
-// Copyright (c) 2019-2023 Tobias Junghans <tobydox@veyon.io>
+// Copyright (c) 2019-2025 Tobias Junghans <tobydox@veyon.io>
 // This file is part of Veyon - https://veyon.io
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -409,21 +409,11 @@ QStringList LdapDirectory::computerLocationEntries( const QString& locationName
 	{
 		const auto computerHostNames = computersByHostName();
 
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-		auto memberComputersSet = QSet<QString>( memberComputers.begin(), memberComputers.end() );
-		const auto computerHostNameSet = QSet<QString>( computerHostNames.begin(), computerHostNames.end() );
-#else
-		auto memberComputersSet = memberComputers.toSet();
-		const auto computerHostNameSet = computersByHostName().toSet();
-#endif
+		auto memberComputersSet = qsetFromList(memberComputers);
+		const auto computerHostNameSet = qsetFromList(computersByHostName());
 
 		// then return intersection of filtered computer list and group members
-		const auto computerIntersection = memberComputersSet.intersect( computerHostNameSet );
-#if QT_VERSION >= QT_VERSION_CHECK(5, 14, 0)
-		return { computerIntersection.begin(), computerIntersection.end() };
-#else
-		return computerIntersection.toList();
-#endif
+		return qlistFromSet(memberComputersSet.intersect(computerHostNameSet));
 	}
 
 	return memberComputers;
