@@ -1,4 +1,4 @@
-// Copyright (c) 2019-2023 Tobias Junghans <tobydox@veyon.io>
+// Copyright (c) 2019-2025 Tobias Junghans <tobydox@veyon.io>
 // This file is part of Veyon - https://veyon.io
 // SPDX-License-Identifier: LGPL-2.0-or-later
 
@@ -39,7 +39,7 @@ NetworkObjectList LdapNetworkObjectDirectory::queryParents( const NetworkObject&
 		return { NetworkObject( NetworkObject::Type::Location,
 								m_ldapDirectory.locationsOfComputer( object.directoryAddress() ).value( 0 ) ) };
 	case NetworkObject::Type::Location:
-		return { NetworkObject( NetworkObject::Type::Root ) };
+		return {rootObject()};
 	default:
 		break;
 	}
@@ -52,19 +52,19 @@ NetworkObjectList LdapNetworkObjectDirectory::queryParents( const NetworkObject&
 void LdapNetworkObjectDirectory::update()
 {
 	const auto locations = m_ldapDirectory.computerLocations();
-	const NetworkObject rootObject( NetworkObject::Type::Root );
 
-	for( const auto& location : qAsConst( locations ) )
+	for( const auto& location : std::as_const( locations ) )
 	{
 		const NetworkObject locationObject( NetworkObject::Type::Location, location );
 
-		addOrUpdateObject( locationObject, rootObject );
+		addOrUpdateObject(locationObject, rootObject());
 
 		updateLocation( locationObject );
 	}
 
-	removeObjects( NetworkObject( NetworkObject::Type::Root ), [locations]( const NetworkObject& object ) {
-		return object.type() == NetworkObject::Type::Location && locations.contains( object.name() ) == false; } );
+	removeObjects(rootObject(), [locations](const NetworkObject& object) {
+		return object.type() == NetworkObject::Type::Location && locations.contains(object.name()) == false;
+	});
 }
 
 
@@ -73,7 +73,7 @@ void LdapNetworkObjectDirectory::updateLocation( const NetworkObject& locationOb
 {
 	const auto computers = m_ldapDirectory.computerLocationEntries( locationObject.name() );
 
-	for( const auto& computer : qAsConst( computers ) )
+	for( const auto& computer : std::as_const( computers ) )
 	{
 		const auto hostObject = computerToObject( &m_ldapDirectory, computer );
 		if( hostObject.type() == NetworkObject::Type::Host )
@@ -154,7 +154,7 @@ NetworkObjectList LdapNetworkObjectDirectory::queryHosts( NetworkObject::Attribu
 	NetworkObjectList hostObjects;
 	hostObjects.reserve( computers.size() );
 
-	for( const auto& computer : qAsConst(computers) )
+	for( const auto& computer : std::as_const(computers) )
 	{
 		const auto hostObject = computerToObject( &m_ldapDirectory, computer );
 		if( hostObject.isValid() )
