@@ -1,7 +1,7 @@
 /*
  * LinuxUserFunctions.h - declaration of LinuxUserFunctions class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -24,6 +24,8 @@
 
 #pragma once
 
+#include <QDBusConnection>
+
 #include "LogonHelper.h"
 #include "PlatformUserFunctions.h"
 
@@ -54,6 +56,8 @@ public:
 	static QVariant getUserProperty(const QString& userPath, const QString& property, bool logErrors = true);
 
 private:
+	QDBusConnection m_systemBus = QDBusConnection::systemBus();
+
 	static constexpr auto AuthHelperTimeout = 10000;
 
 	LogonHelper m_logonHelper{};
