@@ -1,7 +1,7 @@
 /*
  * ScreenLockFeaturePlugin.cpp - implementation of ScreenLockFeaturePlugin class
  *
- * Copyright (c) 2017-2021 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -28,13 +28,14 @@
 #include "FeatureWorkerManager.h"
 #include "LockWidget.h"
 #include "PlatformCoreFunctions.h"
+#include "PlatformSessionFunctions.h"
 #include "VeyonServerInterface.h"
 
 
 ScreenLockFeaturePlugin::ScreenLockFeaturePlugin( QObject* parent ) :
 	QObject( parent ),
 	m_screenLockFeature( QStringLiteral( "ScreenLock" ),
-						 Feature::Mode | Feature::AllComponents,
+						 Feature::Flag::Mode | Feature::Flag::AllComponents,
 						 Feature::Uid( "ccb535a2-1d24-4cc1-a709-8b47d2b2ac79" ),
 						 Feature::Uid(),
 						 tr( "Lock" ), tr( "Unlock" ),
@@ -44,7 +45,7 @@ ScreenLockFeaturePlugin::ScreenLockFeaturePlugin( QObject* parent ) :
 							 "the screens are blacked." ),
 						 QStringLiteral(":/screenlock/system-lock-screen.png") ),
 	m_lockInputDevicesFeature( QStringLiteral( "InputDevicesLock" ),
-							   Feature::Mode | Feature::AllComponents | Feature::Internal,
+							   Feature::Flag::Mode | Feature::Flag::AllComponents | Feature::Flag::Meta,
 							   Feature::Uid( "e4a77879-e544-4fec-bc18-e534f33b934c" ),
 							   {},
 							   tr( "Lock input devices" ), tr( "Unlock input devices" ),
@@ -111,6 +112,12 @@ bool ScreenLockFeaturePlugin::handleFeatureMessage( VeyonServerInterface& server
 			return true;
 		}
 
+		if( VeyonCore::platform().sessionFunctions().currentSessionHasUser() == false )
+		{
+			vDebug() << "not locking screen since not running in a user session";
+			return true;
+		}
+
 		// forward message to worker
 		server.featureWorkerManager().sendMessageToManagedSystemWorker( message );
 
