@@ -1,7 +1,7 @@
 /*
  * TestingCommandLinePlugin.cpp - implementation of TestingCommandLinePlugin class
  *
- * Copyright (c) 2017-2022 Tobias Junghans <tobydox@veyon.io>
+ * Copyright (c) 2017-2025 Tobias Junghans <tobydox@veyon.io>
  *
  * This file is part of Veyon - https://veyon.io
  *
@@ -58,7 +58,7 @@ QString TestingCommandLinePlugin::commandHelp( const QString& command ) const
 CommandLinePluginInterface::RunResult TestingCommandLinePlugin::handle_checkaccess( const QStringList& arguments )
 {
 
-	switch( AccessControlProvider().checkAccess( arguments.value( 0 ), arguments.value( 1 ), { arguments.value( 2 ) } ) )
+	switch (AccessControlProvider().checkAccess(arguments.value(0), arguments.value(1), {arguments.value(2)}).access)
 	{
 	case AccessControlProvider::Access::Allow: printf( "[TEST]: CheckAccess: ALLOW\n" ); return Successful;
 	case AccessControlProvider::Access::Deny: printf( "[TEST]: CheckAccess: DENY\n" ); return Successful;
@@ -88,9 +88,11 @@ CommandLinePluginInterface::RunResult TestingCommandLinePlugin::handle_authorize
 
 CommandLinePluginInterface::RunResult TestingCommandLinePlugin::handle_accesscontrolrules( const QStringList& arguments )
 {
-	switch( AccessControlProvider().processAccessControlRules( arguments.value( 0 ), arguments.value( 1 ),
-															   arguments.value( 2 ), arguments.value( 3 ),
-															   QStringList( arguments.value( 4 ) ) ) )
+	AccessControlProvider provider;
+	const auto rule = provider.processAccessControlRules(arguments.value(0), arguments.value(1),
+														 arguments.value(2), arguments.value(3),
+														 QStringList(arguments.value(4)));
+	switch(rule ? rule->action() : AccessControlRule::Action::None)
 	{
 	case AccessControlRule::Action::Allow: printf( "[TEST]: AccessControlRules: ALLOW\n" ); return Successful;
 	case AccessControlRule::Action::Deny: printf( "[TEST]: AccessControlRules: DENY\n" ); return Successful;
@@ -129,5 +131,5 @@ CommandLinePluginInterface::RunResult TestingCommandLinePlugin::handle_ping( con
 		return NotEnoughArguments;
 	}
 
-	return VeyonCore::platform().networkFunctions().ping( arguments.first() ) ? Successful : Failed;
+	return VeyonCore::platform().networkFunctions().ping( arguments.first() ) == PlatformNetworkFunctions::PingResult::ReplyReceived ? Successful : Failed;
 }
